Define a response that occurs when the first listed process finishes
Source:R/model_definition.R
first_of.RdDefine a response that occurs when the first listed process finishes

R/model_definition.R
first_of.RdDefine a response that occurs when the first listed process finishes